@@ -26,7 +26,7 @@ class Message(base.NotmuchObject):
     package from Python's standard library.  You could e.g. create
     this as such::
 
-       notmuch_msg = db.get_message(msgid)  # or from a query
+       notmuch_msg = db.find(msgid)  # or from a query
        parser = email.parser.BytesParser(policy=email.policy.default)
        with notmuch_msg.path.open('rb) as fp:
            email_msg = parser.parse(fp)
@@ -80,12 +80,6 @@ class Message(base.NotmuchObject):
     def messageid(self):
         """The message ID as a string.
 
-        The message ID is decoded with the ignore error handler.  This
-        is fine as long as the message ID is well formed.  If it is
-        not valid ASCII then this will be lossy.  So if you need to be
-        able to write the exact same message ID back you should use
-        :attr:`messageidb`.
-
         Note that notmuch will decode the message ID value and thus
         strip off the surrounding ``<`` and ``>`` characters.  This is
         different from Python's :mod:`email` package behaviour which
@@ -246,8 +240,7 @@ class Message(base.NotmuchObject):
         :param header: Case-insensitive header name to retrieve.
         :type header: str or bytes
 
-        :returns: The header value, an empty string if the header is
-           not present.
+        :returns: The header value.
         :rtype: str
 
         :raises LookupError: if the header is not present.
@@ -349,7 +342,7 @@ class Message(base.NotmuchObject):
         and thus are only recommended if you know there to be only one
         value.
 
-        Instead the map has an additional :meth:`PropertiesMap.all`
+        Instead the map has an additional :meth:`PropertiesMap.getall`
         method which can be used to retrieve all properties of a given
         key.  This method also allows iterating of a a subset of the
         keys starting with a given prefix.
@@ -610,7 +603,7 @@ class PropertiesMap(base.NotmuchObject, collections.abc.MutableMapping):
     def getall(self, prefix='', *, exact=False):
         """Return an iterator yielding all properties for a given key prefix.
 
-        The returned iterator yields all peroperties which start with
+        The returned iterator yields all properties which start with
         a given key prefix as ``(key, value)`` namedtuples.  If called
         with ``exact=True`` then only properties which exactly match
         the prefix are returned, those a key longer than the prefix
@@ -655,7 +648,6 @@ class PropertiesIter(base.NotmuchIter):
 
     def __next__(self):
         if not self._fn_valid(self._iter_p):
-            self._destroy()
             raise StopIteration
         key = capi.lib.notmuch_message_properties_key(self._iter_p)
         value = capi.lib.notmuch_message_properties_value(self._iter_p)
