@@ -41,6 +41,8 @@ done
 # Ensure NOTMUCH_SRCDIR and NOTMUCH_BUILDDIR are set.
 . $(dirname "$0")/../test/export-dirs.sh || exit 1
 
+. "$NOTMUCH_SRCDIR/test/test-vars.sh" || exit 1
+
 # Where to run the tests
 TEST_DIRECTORY=$NOTMUCH_BUILDDIR/performance-test
 
@@ -208,6 +210,11 @@ print_header ()
     printf "\t\t\tWall(s)\tUsr(s)\tSys(s)\tRes(K)\tIn/Out(512B)\n"
 }
 
+print_emacs_header ()
+{
+    printf "\t\t\tWall(s)\tGCs\tGC time(s)\n"
+}
+
 time_run ()
 {
     printf "  %-22s" "$1"
